#include "ofApp.h"

//--------------------------------------------------------------
void ofApp::setup(){	
    ofBackground(255);
    ofSetOrientation(OF_ORIENTATION_DEFAULT);
    
    camImg.load("images/camera.png");
    libImg.load("images/library.png");
    
    camRect.set(20, 20, camImg.getWidth(), camImg.getHeight());
    libRect.set(camImg.getWidth() + 40, 20, libImg.getWidth(), libImg.getHeight());
    
    radius=20;
    opacity=150;
    animated = true;


}


//--------------------------------------------------------------
void ofApp::update(){
    if(camera.getImageUpdated()){
        
        photo.setFromPixels(camera.getPixelsRef());
        colorPixels.allocate(photo.getWidth(),photo.getHeight(),OF_IMAGE_COLOR);
        pixels=photo.getPixels();
         
         for(int x=0; x<photo.getWidth(); x+=10){
             for(int y=0; y<photo.getHeight(); y+=10){
                 ofColor myColor=pixels.getColor(x,y);
                 colorPixels.setColor(x,y,myColor);
             }
         }

        imgPos.x = 0;
        imgPos.y = camRect.getBottom() + 20;
        
        camera.close();
    }
}

//--------------------------------------------------------------
void ofApp::draw(){

    if(photo.isAllocated()){
        //photo.draw(imgPos);
        
        for(int x=0; x<photo.getWidth(); x+=10){
            for(int y=0; y<photo.getHeight(); y+=10){
                ofSetColor(colorPixels.getColor(x,y),opacity);
                if(animated) {
                    ofDrawCircle(x,y,ofRandom(radius));
                }else{
                    ofDrawCircle(x,y,radius);
                }
            }
        }
    }
    
    camImg.draw(camRect);
    libImg.draw(libRect);
}

//--------------------------------------------------------------
void ofApp::exit() {
}


//--------------------------------------------------------------
void ofApp::touchDown(ofTouchEventArgs & touch){
	if( camRect.inside(touch.x, touch.y) ){
        camera.setMaxDimension(MAX(1024, ofGetHeight()));
        camera.openCamera();
    }else if( libRect.inside(touch.x, touch.y) ){
        camera.setMaxDimension(MAX(1024, ofGetHeight()));
        camera.openLibrary();
    }else{
        prePoint.x = touch.x;
        prePoint.y = touch.y;
    }
}

//--------------------------------------------------------------
void ofApp::touchMoved(ofTouchEventArgs & touch){
    opacity=ofMap(touch.x,0,ofGetWidth(),0,255);
    radius=ofMap(touch.y,0,ofGetHeight(),0,150);
    
	/*if(touch.id == 0){
		imgPos.x += touch.x-prePoint.x;
		imgPos.y += touch.y-prePoint.y;
        
        prePoint.x = touch.x;
        prePoint.y = touch.y;
	}	*/
}

//--------------------------------------------------------------
void ofApp::touchUp(ofTouchEventArgs & touch){	
    
}

//--------------------------------------------------------------
void ofApp::touchDoubleTap(ofTouchEventArgs & touch){
    animated=!animated;
    
}

//--------------------------------------------------------------
void ofApp::touchCancelled(ofTouchEventArgs & touch){
    
}

//--------------------------------------------------------------
void ofApp::lostFocus() {
    
}

//--------------------------------------------------------------
void ofApp::gotFocus() {
    
}

//--------------------------------------------------------------
void ofApp::gotMemoryWarning() {
    
}

//--------------------------------------------------------------
void ofApp::deviceOrientationChanged(int newOrientation){
    
}
